var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/checkbox.tsx
import { isVNode as _isVNode2, createVNode as _createVNode2, mergeProps as _mergeProps2, Fragment as _Fragment } from "vue";
import { h as h3, defineComponent as defineComponent3, computed as computed3, onMounted, cloneVNode, watch as watch2 } from "vue";
import { chakra as chakra2, omitThemingProps, useMultiStyleConfig } from "@chakra-ui/vue-system";
import { SNAO, vueThemingProps as vueThemingProps2, getValidChildren } from "@chakra-ui/vue-utils";
import * as checkbox from "@zag-js/checkbox";
import { normalizeProps, useMachine, mergeProps } from "@zag-js/vue";
import { useIds } from "@chakra-ui/vue-composables";
import { filterUndefined, mergeWith, pick } from "@chakra-ui/utils";
import { useFormControlContext } from "@chakra-ui/c-form-control";

// src/checkbox-icon.tsx
import { isVNode as _isVNode, mergeProps as _mergeProps, createVNode as _createVNode } from "vue";
import { useMotions } from "@vueuse/motion";
import { defineComponent, computed, onBeforeUnmount } from "vue";
import { chakra } from "@chakra-ui/vue-system";
import { CMotion } from "@chakra-ui/c-motion";
import { genId } from "@chakra-ui/vue-utils";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !_isVNode(s);
}
__name(_isSlot, "_isSlot");
var CheckIcon = defineComponent({
  name: "CheckboxCheckIcon",
  setup(_, {
    attrs,
    slots
  }) {
    const transitionId = `check-icon-${genId()}`;
    const leave = /* @__PURE__ */ __name((done) => {
      const motions = useMotions();
      const instance = motions[transitionId];
      instance == null ? void 0 : instance.leave(() => {
        done();
      });
    }, "leave");
    onBeforeUnmount(() => {
      leave(() => null);
    });
    return () => _createVNode(chakra.svg, _mergeProps({
      "width": "1.2em",
      "viewBox": "0 0 12 10",
      "style": {
        fill: "none",
        strokeWidth: 2,
        stroke: "currentColor",
        strokeDasharray: 16
      }
    }, attrs), {
      default: () => _createVNode("polyline", {
        "points": "1.5 6 4.5 9 10.5 1"
      }, null)
    });
  }
});
var IndeterminateIcon = defineComponent({
  name: "CheckboxIndeterminateIcon",
  setup(_, {
    attrs,
    slots
  }) {
    const transitionId = `indeterminate-icon-${genId()}`;
    const leave = /* @__PURE__ */ __name((done) => {
      const motions = useMotions();
      const instance = motions[transitionId];
      instance == null ? void 0 : instance.leave(() => {
        done();
      });
    }, "leave");
    onBeforeUnmount(() => {
      leave(() => null);
    });
    return () => _createVNode(chakra.svg, _mergeProps({
      "width": "1.2em",
      "viewBox": "0 0 24 24",
      "style": {
        stroke: "currentColor",
        strokeWidth: 4
      }
    }, attrs), {
      default: () => _createVNode("line", {
        "x1": "21",
        "x2": "3",
        "y1": "12",
        "y2": "12"
      }, null)
    });
  }
});
var CCheckboxTransition = defineComponent({
  name: "CCheckboxTransition",
  props: {
    open: Boolean
  },
  setup(props, {
    attrs,
    slots
  }) {
    return () => _createVNode(CMotion, {
      "type": "scale",
      "style": {
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        height: "100%"
      }
    }, {
      default: () => [props.open ? () => _createVNode(chakra.div, null, _isSlot(slots) ? slots : {
        default: () => [slots]
      }) : null]
    });
  }
});
var CheckboxIcon = defineComponent((props, {
  slots,
  attrs
}) => {
  const IconEl = computed(() => props.isIndeterminate ? IndeterminateIcon : CheckIcon);
  return () => _createVNode(IconEl.value, attrs, null);
});
CheckboxIcon.name = "CheckboxIcon";
CheckboxIcon.props = {
  isIndeterminate: Boolean,
  isChecked: Boolean
};

// src/checkbox.tsx
import { genId as genId2 } from "@chakra-ui/vue-utils";

// src/checkbox-group.tsx
import { defineComponent as defineComponent2, computed as computed2, renderSlot } from "vue";
import { createContext, vueThemingProps } from "@chakra-ui/vue-utils";

// src/use-checkbox-group.ts
function useCheckboxGroup(props) {
  const {
    modelValue,
    isDisabled
  } = props;
  function handleChange(value, isChecked) {
    if (!value || !modelValue.value)
      return;
    modelValue.value = isChecked ? [.../* @__PURE__ */ new Set([...modelValue.value, value])] : modelValue.value.filter((v) => String(v) !== String(value));
  }
  __name(handleChange, "handleChange");
  return {
    modelValue,
    isDisabled,
    handleChange
  };
}
__name(useCheckboxGroup, "useCheckboxGroup");

// src/checkbox-group.tsx
var [CheckboxGroupProvider, useCheckboxGroupContext] = createContext({
  strict: false,
  name: "CheckboxGroupContext"
});
var CCheckboxGroup = defineComponent2({
  name: "CCheckboxGroup",
  props: {
    modelValue: {
      type: Object,
      default: () => []
    },
    isDisabled: {
      type: Boolean,
      default: false
    },
    ...vueThemingProps
  },
  emits: ["change", "update:modelValue"],
  setup(props, {
    emit,
    slots
  }) {
    const checkBoxGroupValue = computed2({
      get() {
        return props.modelValue;
      },
      set(value) {
        emit("update:modelValue", value);
      }
    });
    const {
      modelValue,
      handleChange
    } = useCheckboxGroup({
      modelValue: checkBoxGroupValue,
      isDisabled: computed2(() => props.isDisabled)
    });
    const checkboxGroupContext = computed2(() => ({
      size: props.size,
      variant: props.variant,
      isDisabled: props.isDisabled,
      colorScheme: props.colorScheme,
      value: modelValue.value,
      handleChange
    }));
    CheckboxGroupProvider(checkboxGroupContext);
    return () => renderSlot(slots, "default");
  }
});

// src/checkbox.tsx
function _isSlot2(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !_isVNode2(s);
}
__name(_isSlot2, "_isSlot");
var CCheckboxControl = chakra2("span", {
  baseStyle: {
    display: "inline-flex",
    alignItems: "center",
    justifyContent: "center",
    verticalAlign: "top",
    userSelect: "none",
    flexShrink: 0
  }
});
var CLabel = chakra2("label", {
  baseStyle: {
    cursor: "pointer",
    display: "inline-flex",
    alignItems: "center",
    verticalAlign: "top",
    position: "relative"
  }
});
var CCheckbox = defineComponent3({
  name: "CCheckbox",
  props: {
    modelValue: {
      type: Boolean,
      default: false
    },
    value: [String, Number],
    id: String,
    isIndeterminate: Boolean,
    isFocusable: Boolean,
    isRequired: Boolean,
    isInvalid: Boolean,
    isDisabled: Boolean,
    isReadonly: Boolean,
    defaultChecked: Boolean,
    name: String,
    "aria-label": String,
    "aria-labelledby": String,
    "aria-invalid": Boolean,
    "aria-describedby": String,
    spacing: {
      type: SNAO,
      default: "0.5rem"
    },
    iconColor: String,
    iconSize: [String, Number],
    icon: Object,
    inputProps: Object,
    ...vueThemingProps2
  },
  emits: ["change", "update:modelValue"],
  setup(props, {
    slots,
    attrs,
    emit
  }) {
    const group = useCheckboxGroupContext(computed3(() => ({})));
    const ownProps = computed3(() => omitThemingProps(props));
    const mergedProps = computed3(() => mergeWith({}, group.value, props, attrs));
    const styles = useMultiStyleConfig("Checkbox", mergedProps);
    const inheritedFormControlProps = useFormControlContext(mergedProps);
    const id = genId2();
    const [rootId, inputId, controlId, labelId] = useIds(`chakra-checkbox-${id}`, "root", "input", "control", "label");
    const machineContext = computed3(() => {
      var _a, _b, _c, _d;
      const _inheritedFormControlProps = pick((inheritedFormControlProps == null ? void 0 : inheritedFormControlProps.value) || {}, ["isRequired", "isDisabled", "isInvalid", "isReadOnly"]);
      const cleanedContextProps = filterUndefined({
        readonly: (_a = _inheritedFormControlProps == null ? void 0 : _inheritedFormControlProps.isReadOnly) == null ? void 0 : _a.value,
        required: (_b = _inheritedFormControlProps == null ? void 0 : _inheritedFormControlProps.isRequired) == null ? void 0 : _b.value,
        disabled: (_c = _inheritedFormControlProps == null ? void 0 : _inheritedFormControlProps.isDisabled) == null ? void 0 : _c.value,
        invalid: (_d = _inheritedFormControlProps == null ? void 0 : _inheritedFormControlProps.isInvalid) == null ? void 0 : _d.value
      });
      const cleanedOwnProps = filterUndefined({
        required: props.isRequired,
        disabled: props.isDisabled,
        invalid: props.isInvalid,
        readonly: props.isReadonly,
        focusable: props.isFocusable,
        "aria-invalid": props["aria-invalid"],
        "aria-label": props["aria-label"],
        "aria-labelledby": props["aria-labelledby"],
        "aria-describedby": props["aria-describedby"]
      });
      return mergeWith({}, cleanedContextProps, cleanedOwnProps, {
        value: props.value,
        defaultChecked: props.defaultChecked,
        indeterminate: props.isIndeterminate
      });
    });
    const context = computed3(() => ({
      id,
      ids: {
        root: rootId.value,
        input: inputId.value,
        control: controlId.value,
        labelId: labelId.value
      },
      ...machineContext.value
    }));
    const [state, send] = useMachine(
      checkbox.machine({
        id: "chakra-ui-checkbox-machine"
      }),
      {
        context
      }
    );
    const api = computed3(() => checkbox.connect(state.value, send, normalizeProps));
    const iconStyles = computed3(() => ({
      opacity: api.value.isChecked || api.value.isIndeterminate ? 1 : 0,
      transform: api.value.isChecked || api.value.isIndeterminate ? "scale(1)" : "scale(0.95)",
      fontSize: props.iconSize,
      color: props.iconColor,
      ...styles.value.icon
    }));
    const clonedIcon = computed3(() => cloneVNode(h3(CheckboxIcon), {
      __css: iconStyles.value,
      isIndeterminate: api.value.isIndeterminate,
      isChecked: api.value.isChecked
    }));
    onMounted(() => {
      if (props.defaultChecked && api.value) {
        api.value.setChecked(true);
      }
      if (api.value) {
        if (group.value.value && ownProps.value.value) {
          const isChecked = group.value.value.includes(ownProps.value.value);
          api.value.setChecked(isChecked);
        }
      }
    });
    watch2(() => api.value.isChecked, (value) => {
      emit("update:modelValue", value);
      emit("change", value);
      if (group.value.handleChange && ownProps.value.value) {
        group.value.handleChange(ownProps.value.value, value);
      }
    });
    watch2(() => props.modelValue, (value) => {
      api.value.setChecked(value);
    });
    const inputProps = computed3(() => mergeProps(api.value.inputProps, {
      onChange() {
        if (api.value.isIndeterminate && !api.value.isReadOnly) {
          api.value.setIndeterminate(false);
          api.value.setChecked(true);
        }
      }
    }));
    return () => {
      const children = getValidChildren(slots);
      const hasChildren = children.length > 0;
      return _createVNode2(chakra2.div, {
        "sx": {
          "> div": styles.value.container
        }
      }, {
        default: () => _createVNode2(CLabel, _mergeProps2({
          "__label": "checkbox"
        }, api.value.rootProps, {
          "__css": styles.value.container
        }), {
          default: () => _createVNode2(_Fragment, null, [_createVNode2("input", _mergeProps2({
            "class": "chakra-checkbox__input"
          }, inputProps.value), null), _createVNode2(CCheckboxControl, _mergeProps2({
            "__label": "checkbox__control",
            "__css": styles.value.control
          }, api.value.controlProps), {
            default: () => clonedIcon.value
          }), hasChildren && _createVNode2(chakra2.span, _mergeProps2({
            "label": "checkbox__label"
          }, api.value.labelProps, {
            "__css": {
              marginStart: props.spacing,
              ...styles.value.label
            }
          }), _isSlot2(slots) ? slots : {
            default: () => [slots]
          })])
        })
      });
    };
  }
});
export {
  CCheckbox,
  CCheckboxGroup,
  useCheckboxGroupContext
};
